@@ -8,31 +8,23 @@ OC.L10N.register(
     "Folder name" : "Anv teuliad",
     "Username" : "anv implijer",
     "Password" : "Ger-tremen",
-    "New folder" : "Heuliad nevez",
+    "New folder" : "Teuliad nevez",
     "Credentials" : "Kretaatoù",
     "Move" : "Diplasañ",
     "Share" : "Rannan",
     "All articles" : "Pep pennad",
     "Settings" : "Arventennoù",
+    "Documentation" : "Diellvadur",
     "Rename" : "Adenvel",
     "Delete" : "Dilemel",
     "Newest first" : "An hini nevesañ da gentañ",
     "Oldest first" : "An hini kozhoñ da gentañ",
+    "Next" : "War-lerc'h",
     "by" : "gant",
     "Play audio" : "Loc'hañ an audio",
     "Download video" : "Pellkargañ ar video",
     "Open website" : "Digor al lec'hienn-web",
     "Title" : "Titl",
-    "Refresh" : "Freskaat",
-    "Description" : "Diskrivadur",
-    "Folder" : "Teuliad",
-    "New Folder" : "Teuliad nevez",
-    "Create" : "Krouiñ",
-    "Menu" : "Roll",
-    "Dismiss" : "Arrest",
-    "Import" : "Emporzhiañ ",
-    "Help" : "Skoazell",
-    "Documentation" : "Diellvadur",
-    "Report a bug" : "Dugas ur gudenn"
+    "Refresh" : "Freskaat"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
