@@ -17,14 +17,6 @@ OC.L10N.register(
     "Delete" : "Obriši",
     "Previous" : "Prethodno",
     "by" : "od strane",
-    "from" : "od",
-    "Title" : "Naslov",
-    "Description" : "Opis",
-    "Folder" : "Fasikla",
-    "Create" : "Kreiraj",
-    "Collapse" : "Proširi",
-    "Import" : "Uvezi",
-    "Export" : "Izvezi",
-    "Help" : "Pomoć"
+    "Title" : "Naslov"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
