@@ -1,11 +1,6 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
-    "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
-    "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
-    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
     "Unread articles" : "Μη αναγνωσμένα άρθρα",
     "News" : "Νέα",
     "Shared with me" : "Διαμοιρασμένα με εμένα",
@@ -59,16 +54,13 @@ OC.L10N.register(
     "Default order" : "Προεπιλεγμένη σειρά",
     "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
     "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
-    "Unread updated" : "Μη αναγνωσμένο ενημερώθηκε",
-    "Ignore updated" : "Αγνόηση ενημέρωσης",
     "Previous" : "Προηγούμενο",
     "Next" : "Επόμενο",
     "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
     "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
     "Close details" : "Κλείσιμο λεπτομερειών",
-    "by" : "από",
-    "from" : "από",
     "shared by" : "σε κοινή χρήση από",
+    "by" : "από",
     "Play audio" : "Αναπαραγωγή ήχου",
     "Download audio" : "Λήψη ήχου",
     "Download video" : "Κατεβάστε το βίντεο",
@@ -76,6 +68,7 @@ OC.L10N.register(
     "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
     "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
     "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
+    "Please wait" : "Παρακαλούμε περιμένετε",
     "Last update" : "Τελευταία ενημέρωση",
     "Title" : "Τίτλος",
     "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
@@ -96,39 +89,6 @@ OC.L10N.register(
     "Subscribe to" : "Εγγραφείτε στο",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
     "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
-    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα",
-    "No articles available" : "Δεν υπάρχουν διαθέσιμα άρθρα",
-    "No unread articles available" : "Κανένα αδιάβαστο άρθρο διαθέσιμο",
-    "Star article" : "Επισήμανση με αστέρι",
-    "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
-    "No users found" : "Δεν βρέθηκαν χρήστες",
-    "Share on social media" : "Κοινοποίηση στα μέσα κοινωνικής δικτύωσης",
-    "Description" : "Περιγραφή",
-    "Toggle expand article in compact view" : "Εναλλαγή επέκτασης άρθρου στη συμπαγή προβολή",
-    "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
-    "Folder" : "Φάκελος",
-    "Go back" : "Μετακίνηση πίσω",
-    "New Folder" : "Νέος φάκελος",
-    "Create" : "Δημιουργία",
-    "Update failed more than 50 times" : "Η αποστολή απέτυχε πάνω από 50 φορές",
-    "Deleted feed" : "Διαγραφή ροής",
-    "Undo delete feed" : "Αναίρεση διαγραφής ροής",
-    "Menu" : "Μενού",
-    "Open feed URL" : "Ανοίξτε τη διεύθυνση URL ροής",
-    "Dismiss" : "Αποδέσμευση",
-    "Collapse" : "Σύμπτυξη",
-    "Deleted folder" : "Διαγραφή φακέλου",
-    "Undo delete folder" : "Αναίρεση διαγραφής φακέλου",
-    "Compact view" : "Συμπαγής προβολή",
-    "Expand articles on key navigation" : "Ανάπτυξη των άρθρων κατά την πλοήγηση με πλήκτρα",
-    "Subscriptions (OPML)" : "Συνδρομές (OPML)",
-    "Import" : "Εισαγωγή",
-    "Export" : "Εξαγωγή",
-    "Error when importing: File does not contain valid OPML" : "Σφάλμα κατά την εισαγωγή: Το αρχείο δεν περιέχει έγκυρο OPML",
-    "Error when importing: OPML is does neither contain feeds nor folders" : "Σφάλμα εισαγωγής: Το OPML δεν περιέχει ούτε τροφοδοσίες ούτε φακέλους",
-    "Unread/Starred Articles" : "Με αστέρι/Μη αναγνωσμένα Άρθρα",
-    "Error when importing: file does not contain valid JSON" : "Σφάλμα κατά την εισαγωγή: το αρχείο δεν περιέχει έγκυρο JSON",
-    "Help" : "Βοήθεια",
-    "Report a bug" : "Αναφορά σφάλματος"
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα"
 },
 "nplurals=2; plural=(n != 1);");
