@@ -1,12 +1,6 @@
 OC.L10N.register(
     "news",
     {
-    "Request failed, network connection unavailable!" : "Užklausa nepavyko, tinklo ryšys neprieinamas!",
-    "Request unauthorized. Are you logged in?" : "Užklausa neleidžiama. Ar esate prisijungę?",
-    "Request forbidden. Are you an administrator?" : "Užklausa draudžiama. Ar esate administratorius?",
-    "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
-    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
-    "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
     "News feeds" : "Naujienų kanalai",
     "Unread articles" : "Neskaityti straipsniai",
     "News" : "Naujienos",
@@ -71,8 +65,6 @@ OC.L10N.register(
     "Default order" : "Numatytoji tvarka",
     "Enable full text" : "Įjungti raiškųjį tekstą",
     "Disable full text" : "Išjungti raiškųjį tekstą",
-    "Unread updated" : "Žymėti atnaujintus straipsnius kaip neskaitytus",
-    "Ignore updated" : "Nepaisyti atnaujintų straipsnių",
     "Previous Item" : "Ankstesnis elementas",
     "Previous" : "Ankstesnis",
     "Next Item" : "Kitas elementas",
@@ -80,21 +72,15 @@ OC.L10N.register(
     "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
     "Mark unread" : "Žymėti kaip neskaitytą",
     "Close details" : "Užverti išsamesnę informaciją",
-    "by" : " ",
-    "from" : "iš",
     "shared by" : "bendrina",
+    "by" : " ",
     "Play audio" : "Atkurti garso įrašą",
     "Download audio" : "Atsisiųsti garso įrašą",
     "Download video" : "Atsisiųsti vaizdo įrašą",
-    "{num} seconds" : "{num} sek.",
-    "{num} minutes ago" : "prieš {num} min.",
-    "{num} hours ago" : "prieš {num} val.",
-    "{num} days ago" : "prieš {num} d.",
-    "{num} months ago" : "prieš {num} mėn.",
-    "{num} years ago" : "prieš {num} m.",
     "Open website" : "Atverti svetainę",
     "Keep article unread" : "Palikti straipsnį neskaitytą",
     "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
+    "Please wait" : "Prašome palaukti",
     "Last update" : "Paskutinis atnaujinimas",
     "Next update" : "Kitas atnaujinimas",
     "Title" : "Pavadinimas",
@@ -118,42 +104,6 @@ OC.L10N.register(
     "Unread Articles" : "Neskaityti straipsniai",
     "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
     "How to set up the operating system cron" : "Kaip nusistatyti operacinės sistemos cron",
-    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API",
-    "No articles available" : "Nėra straipsnių",
-    "No unread articles available" : "Nėra neperskaitytų straipsnių",
-    "Star article" : "Pažymėti straipsnį žvaigždute",
-    "Unstar article" : "Nebežymėti straipsnio žvaigždute",
-    "Share with users" : "Bendrinti su naudotojais",
-    "No users found" : "Nerasta jokių naudotojų",
-    "Error while searching for users" : "Klaida ieškant naudotojų",
-    "Share on social media" : "Bendrinti socialiniuose tinkluose",
-    "I wanted you to see this article" : "Norėjau, kad pamatytum šį straipsnį",
-    "Check out this article" : "Perskaityk šį straipsnį",
-    "Description" : "Aprašas",
-    "Mark current article's feed/folder read" : "Žymėti esamo straipsnio kanalą/aplanką kaip skaitytą",
-    "Folder" : "Aplankas",
-    "Go back" : "Grįžti",
-    "New Folder" : "Naujas aplankas",
-    "Create" : "Sukurti",
-    "Update failed more than 50 times" : "Atnaujinimas daugiau kaip 50 kartų patyrė nesėkmę",
-    "Deleted feed" : "Ištrintas kanalas",
-    "Undo delete feed" : "Atšaukti kanalo ištrynimą",
-    "Menu" : "Meniu",
-    "Open feed URL" : "Atverti kanalo URL",
-    "Dismiss" : "Pašalinti",
-    "Collapse" : "Suskleisti",
-    "Deleted folder" : "Ištrintas aplankas",
-    "Undo delete folder" : "Atšaukti aplanko ištrynimą",
-    "Compact view" : "Rodyti tik antraštes",
-    "Expand articles on key navigation" : "Rodyti pilnus straipsnius perjungiant klavišais",
-    "Subscriptions (OPML)" : "Prenumeratos (OPML)",
-    "Import" : "Importuoti",
-    "Export" : "Eksportuoti",
-    "Error when importing: File does not contain valid OPML" : "Klaida importuojant: Faile nėra tinkamo OPML",
-    "Error when importing: OPML is does neither contain feeds nor folders" : "Klaida, importuojant: OPML faile nėra nei kanalų, nei aplankų",
-    "Unread/Starred Articles" : "Neskaityti/Pažymėti žvaigždute straipsniai",
-    "Error when importing: file does not contain valid JSON" : "Klaida importuojant: faile nėra teisingo JSON",
-    "Help" : "Pagalba",
-    "Report a bug" : "Pranešti apie klaidą"
+    "Install and set up a faster parallel updater that uses the News app's update API" : "Įdiekite ir nusistatykite greitesnę lygiagrečią atnaujinimo programą, kuri naudoja Naujienų programėlės atnaujinimo API"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
